DOM(document object module) for JSONA
DOM be constructed for data-oriented analysis where each node wraps a part of the syntax tree with additional information and functionality.
Re-exports
pub use error::*;pub use keys::*;pub use node::*;pub use query_keys::*;pub use visitor::*;